@@ -21,6 +21,11 @@ use lib 'lib', 'blib/arch';
 use Prima qw(Application Buttons GLWidget);
 use OpenGL qw(:glfunctions :glconstants);
 
+my $win32     = $^O =~ /win32/i;
+my $show_off  = $::application->get_system_value( sv::LayeredWidgets );
+my $composite = $::application->get_system_value( sv::CompositeDisplay );
+my $gl_buffer = 1;
+
 sub icosahedron
 {
 	my $config = shift;
@@ -84,8 +89,8 @@ sub init
 	if ( $config-> {use_lighting} ) {
 		# Initialize material property, light source, lighting model, 
 		# and depth buffer.
-		my @mat_specular = ( 1.0, 1.0, 0.0, 1.0 );
-		my @mat_diffuse  = ( 0.0, 1.0, 1.0, 1.0 );
+		my @mat_specular = ( 1.0, 1.0, 0.0, 0.8 );
+		my @mat_diffuse  = ( 0.0, 1.0, 1.0, 0.8 );
 		my @light_position = ( 1.0, 1.0, 1.0, 0.0 );
 		
 		glMaterialfv_s(GL_FRONT, GL_DIFFUSE, pack("f4",@mat_diffuse));
@@ -96,6 +101,9 @@ sub init
 		glEnable(GL_LIGHTING);
 		glEnable(GL_LIGHT0);
 		glDepthFunc(GL_LESS);
+
+		glEnable(GL_BLEND);
+		glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 	} else {
 		glDisable(GL_LIGHTING);
 		glDisable(GL_LIGHT0);
@@ -106,6 +114,7 @@ sub init
 sub display
 {
 	my $config = shift;
+	glClearColor(0,0,0,0);
 	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 	glPushMatrix();
 	glRotatef(23*sin($config-> {spin}*3.14/180),1,0,0);
@@ -130,6 +139,37 @@ sub reshape
 	glLoadIdentity();
 }
 
+sub reset_gl
+{
+	my ( $widget, $config ) = @_;
+	$widget-> gl_select;
+	init($config);
+	reshape($config);
+	glEnable(GL_DEPTH_TEST);
+}
+
+sub create_gl_widget
+{
+	my ( $top, $config ) = @_;
+
+	return $top-> insert( 'Prima::GLWidget' => 
+		growMode  => gm::Client,
+		layered   => 1,
+		origin    => [0, 0],
+		size      => [ $top-> size ],
+		gl_config => { double_buffer => $gl_buffer, depth_bits => 16 },
+		onCreate  => sub {
+			reset_gl(shift,$config);
+			glEnable(GL_DEPTH_TEST);
+			glRotatef(0.12,1,0,0);
+		},
+		onPaint      => sub { display($config) },
+		onMouseDown  => sub { $config->{grab} = 1 },
+		onMouseUp    => sub { $config->{grab} = 0 },
+	);
+}
+	
+
 sub create_window
 {
 	my %config = (
@@ -145,6 +185,9 @@ sub create_window
 	my $top = Prima::MainWindow-> new(
 		size => [ 300, 300 ],
 		text => 'OpenGL example',
+		layered => $show_off,
+		buffered => 0,
+		backColor => 0,
 		menuItems => [
 			['~Options' => [
 				['*' => '~Rotate' => 'Ctrl+R' => '^R' => sub { 
@@ -157,28 +200,36 @@ sub create_window
 				['*' => '~Frame' => 'Ctrl+F' => '^F' => sub { 
 					$config{use_frame} = $_[0]-> menu-> toggle( $_[1] );
 				}],
+				[],
+				[
+				( $show_off ? '*' : '-' ),
+				'~Layered' => 'Ctrl+Y' => '^Y' => sub { 
+					my $self = shift;
+					$self->layered( $self-> menu-> toggle( shift ));
+					$config{widget}-> send_to_back;
+					$config{widget}-> gl_destroy;
+					$config{widget}-> gl_create( %{$config{widget}->gl_config} );
+					reset_gl($config{widget} , \%config);
+				}],
+				['' => '~Buffered' => sub {
+					my $self = shift;
+					$self->buffered( $self-> menu-> toggle( shift ));
+				}],
+				[($gl_buffer ? '*' : '') => '~GL Double buffer' => sub {
+					my $self = shift;
+					$gl_buffer = $self-> menu-> toggle(shift) ? 1 : 0;
+					# win32 needs that, x11 doesn't
+					$config{widget}->destroy;
+					$config{widget} = create_gl_widget($self, \%config);
+					$config{widget}-> send_to_back;
+				}],
 			]],
 			[],
 			['~Clone' => \&create_window ],
 		],
 	);
-	
-	$config{widget} = $top-> insert( 'Prima::GLWidget' => 
-		pack      => { expand => 1, fill => 'both'},
-		gl_config => { double_buffer => 1, depth_bits => 16 },
-		onCreate  => sub {
-			shift-> gl_select;
-			init(\%config);
-			reshape(\%config);
-			glEnable(GL_DEPTH_TEST);
-			glRotatef(0.12,1,0,0);
-		},
-		onPaint      => sub {
-			display(\%config);
-		},
-		onMouseDown  => sub { $config{grab} = 1 },
-		onMouseUp    => sub { $config{grab} = 0 },
-	);
+
+	$config{widget} = create_gl_widget( $top, \%config );
 	
 	$top-> insert( Timer => 
 		timeout => 5,
